1.0.0 API documentation: GLM_EXT_quaternion_float_precision

| 1.0.0 API documentation

Typedefs
GLM_EXT_quaternion_float_precision
Stable extensions

## Typedefs
typedef qua< float, highp > | highp_quat
| Quaternion of single-precision floating-point numbers using high precision arithmetic in term of ULPs.
typedef qua< float, lowp > | lowp_quat
| Quaternion of single-precision floating-point numbers using high precision arithmetic in term of ULPs.
typedef qua< float, mediump > | mediump_quat
| Quaternion of single-precision floating-point numbers using high precision arithmetic in term of ULPs.

## Detailed Description

Exposes single-precision floating point quaternion type with various precision in term of ULPs.

Include <glm/ext/quaternion_float_precision.hpp> to use the features of this extension.